@@ -1,5 +1,5 @@
-//PickSelectorAction.h: Header file for the PickSelectorAction class (provides support for adding QMaemo5ValueButton with
-//associated QMaemo5ListPickSelector to e.g., the menubar (or other QWidgetAction container)).
+//PickSelectorAction.h: Header file for the PickSelectorAction class (provides support for adding QMaemo5ValueButton / QComboBox with
+//associated QMaemo5ListPickSelector (for QMaemo5ValueButton) to e.g., the menubar (or other QWidgetAction container)).
 
 #ifndef PICKSELECTORACTION_H
 #define PICKSELECTORACTION_H
@@ -7,9 +7,13 @@
 #include <QWidget>
 #include <QWidgetAction>
 #include <QStringList>
-#include <QStringListModel>
-#include <QMaemo5ListPickSelector>
-#include <QMaemo5ValueButton>
+#ifdef Q_WS_MAEMO_5
+    #include <QStringListModel>
+    #include <QMaemo5ListPickSelector>
+    #include <QMaemo5ValueButton>
+#else
+    #include <QComboBox>
+#endif
 
 class PickSelectorAction : public QWidgetAction {
 
@@ -42,7 +46,9 @@ private:
 
     QStringList m_List;
 
+#ifdef Q_WS_MAEMO_5
     QStringListModel *m_pListModel;
+#endif
 
 signals:
 
